%global         majorminor              1.0

%bcond_without	unwind
%bcond_with	docs

Summary:        GStreamer streaming media framework runtime
Name:           gstreamer1
Version:        1.22.5
Release:        5%{?dist}
License:        LGPLv2+
URL:            http://gstreamer.freedesktop.org/
Source0:        http://gstreamer.freedesktop.org/src/gstreamer/gstreamer-%{version}.tar.xz
Source1:        gstreamer1.prov
Source2:        gstreamer1.attr
# fix CVE-2024-47606
# see https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/8094.patch
Patch0001:      8094-1.patch
Patch3000:      gstreamer-inspect-rpm-format.patch

BuildRequires:  meson >= 0.48.0
BuildRequires:  gcc bison flex gettext pkgconfig
BuildRequires:  glib2-devel libxml2-devel check-devel
BuildRequires:  gobject-introspection-devel libcap-devel
BuildRequires:  elfutils-devel bash-completion
%if %{with unwind}
BuildRequires:  libunwind-devel
%endif

%description
GStreamer is a streaming media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new 
plugins.

%package devel
Summary:        Libraries/include files for GStreamer streaming media framework
Requires:       %{name} = %{version}-%{release}
Requires:       glib2-devel libxml2-devel check-devel

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with docs}
%package devel-docs
Summary:         Developer documentation for GStreamer streaming media framework
Requires:        %{name} = %{version}-%{release}
BuildArch:       noarch

%description devel-docs
This %{name}-devel-docs contains developer documentation for the
GStreamer streaming media framework.
%endif

%prep
%autosetup -n gstreamer-%{version} -p1

%build
%meson	\
  -D tests=disabled -D examples=disabled \
  -D ptp-helper-permissions=capabilities \
  %{!?with_unwind:-D libunwind=disabled -D libdw=disabled } \
  -D dbghelp=disabled \
%if %{with docs}
  -D doc=enabled
%else
  -D doc=disabled
%endif
%meson_build

%install
%meson_install
install -m0755 -D %{SOURCE1} %{buildroot}%{_rpmconfigdir}/gstreamer1.prov
install -m0644 -D %{SOURCE2} %{buildroot}%{_rpmconfigdir}/fileattrs/gstreamer1.attr
%find_lang gstreamer-%{majorminor}

%files -f gstreamer-%{majorminor}.lang
%license COPYING
%doc AUTHORS NEWS RELEASE
%{_libdir}/libgstreamer-%{majorminor}.so.*
%{_libdir}/libgstbase-%{majorminor}.so.*
%{_libdir}/libgstcheck-%{majorminor}.so.*
%{_libdir}/libgstcontroller-%{majorminor}.so.*
%{_libdir}/libgstnet-%{majorminor}.so.*

%{_libexecdir}/gstreamer-%{majorminor}/

%dir %{_libdir}/gstreamer-%{majorminor}
%{_libdir}/gstreamer-%{majorminor}/libgstcoreelements.so
%{_libdir}/gstreamer-%{majorminor}/libgstcoretracers.so

%{_libdir}/girepository-1.0/Gst-%{majorminor}.typelib
%{_libdir}/girepository-1.0/GstBase-%{majorminor}.typelib
%{_libdir}/girepository-1.0/GstCheck-%{majorminor}.typelib
%{_libdir}/girepository-1.0/GstController-%{majorminor}.typelib
%{_libdir}/girepository-1.0/GstNet-%{majorminor}.typelib

%{_bindir}/gst-inspect-%{majorminor}
%{_bindir}/gst-launch-%{majorminor}
%{_bindir}/gst-stats-%{majorminor}
%{_bindir}/gst-typefind-%{majorminor}

%{_rpmconfigdir}/gstreamer1.prov
%{_rpmconfigdir}/fileattrs/gstreamer1.attr

%doc %{_mandir}/man1/gst-inspect-%{majorminor}.*
%doc %{_mandir}/man1/gst-launch-%{majorminor}.*
%doc %{_mandir}/man1/gst-stats-%{majorminor}.*
%doc %{_mandir}/man1/gst-typefind-%{majorminor}.*

%{_datadir}/bash-completion/completions/gst-inspect-1.0
%{_datadir}/bash-completion/completions/gst-launch-1.0
%{_datadir}/bash-completion/helpers/gst

%files devel
%dir %{_includedir}/gstreamer-%{majorminor}
%dir %{_includedir}/gstreamer-%{majorminor}/gst
%dir %{_includedir}/gstreamer-%{majorminor}/gst/base
%dir %{_includedir}/gstreamer-%{majorminor}/gst/check
%dir %{_includedir}/gstreamer-%{majorminor}/gst/controller
%dir %{_includedir}/gstreamer-%{majorminor}/gst/net
%{_includedir}/gstreamer-%{majorminor}/gst/*.h
%{_includedir}/gstreamer-%{majorminor}/gst/base/*.h
%{_includedir}/gstreamer-%{majorminor}/gst/check/*.h
%{_includedir}/gstreamer-%{majorminor}/gst/controller/*.h
%{_includedir}/gstreamer-%{majorminor}/gst/net/*.h

%{_libdir}/libgstreamer-%{majorminor}.so
%{_libdir}/libgstbase-%{majorminor}.so
%{_libdir}/libgstcheck-%{majorminor}.so
%{_libdir}/libgstcontroller-%{majorminor}.so
%{_libdir}/libgstnet-%{majorminor}.so

%{_datadir}/gir-1.0/Gst-%{majorminor}.gir
%{_datadir}/gir-1.0/GstBase-%{majorminor}.gir
%{_datadir}/gir-1.0/GstCheck-%{majorminor}.gir
%{_datadir}/gir-1.0/GstController-%{majorminor}.gir
%{_datadir}/gir-1.0/GstNet-%{majorminor}.gir

%{_datadir}/aclocal/gst-element-check-%{majorminor}.m4

%dir %{_datadir}/gstreamer-%{majorminor}/gdb/
%{_datadir}/gstreamer-%{majorminor}/gdb/
%{_datadir}/gdb/auto-load/

%{_libdir}/pkgconfig/gstreamer-%{majorminor}.pc
%{_libdir}/pkgconfig/gstreamer-base-%{majorminor}.pc
%{_libdir}/pkgconfig/gstreamer-controller-%{majorminor}.pc
%{_libdir}/pkgconfig/gstreamer-check-%{majorminor}.pc
%{_libdir}/pkgconfig/gstreamer-net-%{majorminor}.pc

%if %{with docs}
%files devel-docs
%doc %{_datadir}/gtk-doc/html/gstreamer-%{majorminor}
%doc %{_datadir}/gtk-doc/html/gstreamer-libs-%{majorminor}
%doc %{_datadir}/gtk-doc/html/gstreamer-plugins-%{majorminor}
%endif

%changelog
* Fri Dec 13 2024 Wang Guodong <gordonwwang@tencent.com> - 1.22.5-5
- fix CVE-2024-47606

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.5-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.5-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.5-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 1 2023 Shuo Wang <abushwang@tencent.com> - 1.22.5-1
- update to 1.22.5

* Mon Jul 03 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.22.4-1
- Upgrade to upstream version 1.22.4
- Enable unwind

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.20.4-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.20.4-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 5 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.20.4-2
- fix small to make package files more generical

* Mon Dec 5 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.20.4-1
- updated to 1.20.4 for building gstreamer plugins

* Tue Nov 22 2022 Xiaojie Chen <jackxjchen@tencent.com> - 1.20.0-1
- Initial build
